{
    "$graph": [
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "biocontainers/clustal-omega",
                    "class": "DockerRequirement"
                },
                {
                    "packages": [
                        {
                            "package": "clustalo",
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_001591"
                            ]
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#clustalo.cwl/multi_sequence"
                }
            ],
            "baseCommand": "clustalo",
            "arguments": [
                "-i",
                "$(inputs.multi_sequence.path)",
                "--guidetree-out",
                "$(inputs.multi_sequence.nameroot).ph",
                "--threads",
                "$(runtime.cores)"
            ],
            "id": "#clustalo.cwl",
            "stdout": "7bdc09cfeb45676da7d9b93f218dd82116c6059c",
            "outputs": [
                {
                    "type": "File",
                    "label": "Multiple sequence alignment",
                    "id": "#clustalo.cwl/alignment",
                    "outputBinding": {
                        "glob": "7bdc09cfeb45676da7d9b93f218dd82116c6059c"
                    }
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.multi_sequence.nameroot).ph"
                    },
                    "id": "#clustalo.cwl/guide_tree"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "quay.io/biocontainers/paml:4.9--1",
                    "class": "DockerRequirement"
                },
                {
                    "listing": [
                        {
                            "entryname": "paml0-3.ctl",
                            "entry": "seqfile  = $(inputs.sequences.path)\ntreefile = $(inputs.tree.path)\noutfile = results0-3.txt   * main result file name\nnoisy = 9        * 0,1,2,3,9: how much rubbish on the screen\nverbose = 1      * 1:detailed output\nrunmode = 0      * 0:user defined tree\nseqtype = 1      * 1:codons\nCodonFreq = 2    * 0:equal, 1:F1X4, 2:F3X4, 3:F61\nmodel = 0        * 0:one omega ratio for all branches\n                 * 1:separate omega for each branch\n                 * 2:user specified dN/dS ratios for branches\nNSsites = 0 3 \nicode = 0        * 0:universal code\nfix_kappa = 0    * 1:kappa fixed, 0:kappa to be estimated\nkappa = 4        * initial or fixed kappa\nfix_omega = 0    * 1:omega fixed, 0:omega to be estimated\nomega = 5        * initial omega\n                 * RateAncestor = 1\nncatG = 3        * num. of categories in the dG or AdG models of rates\ngetSE = 0        * 0: don't want them, 1: want S.E.s of estimates\n"
                        }
                    ],
                    "class": "InitialWorkDirRequirement"
                },
                {
                    "packages": [
                        {
                            "package": "paml",
                            "specs": [
                                "https://identifiers.org/rrid/RRID:SCR_014932"
                            ]
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#codeml.cwl/sequences"
                },
                {
                    "type": "File",
                    "id": "#codeml.cwl/tree"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "results0-3.txt"
                    },
                    "id": "#codeml.cwl/results"
                }
            ],
            "baseCommand": [
                "codeml",
                "paml0-3.ctl"
            ],
            "id": "#codeml.cwl"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "packages": [
                        {
                            "package": "pal2nal",
                            "specs": [
                                "https://doi.org/10.1093/nar/gkl315"
                            ]
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "label": "nucleotide sequence",
                    "id": "#pal2nal.cwl/nucleotides"
                },
                {
                    "type": "File",
                    "label": "Multiple sequence alignment",
                    "id": "#pal2nal.cwl/protein_alignment"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "label": "Multiple sequence alignment",
                    "id": "#pal2nal.cwl/alignment",
                    "outputBinding": {
                        "glob": "d6387c8b5526439791a50a33390d4b50cb2ac01b"
                    }
                }
            ],
            "baseCommand": "pal2nal.pl",
            "arguments": [
                {
                    "valueFrom": "paml",
                    "prefix": "-output"
                },
                "$(inputs.protein_alignment.path)",
                "$(inputs.nucleotides.path)"
            ],
            "id": "#pal2nal.cwl",
            "stdout": "d6387c8b5526439791a50a33390d4b50cb2ac01b"
        },
        {
            "class": "Workflow",
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/nucleotides"
                },
                {
                    "type": "File",
                    "label": "proteins",
                    "id": "#main/proteins_to_align"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/clustal/alignment",
                    "label": "proteins alignment",
                    "id": "#main/alignment1"
                },
                {
                    "type": "File",
                    "outputSource": "#main/pal2nal/alignment",
                    "label": "nucleotides alignment",
                    "id": "#main/alignment2"
                },
                {
                    "type": "File",
                    "outputSource": "#main/clustal/guide_tree",
                    "label": "guide tree",
                    "id": "#main/guide_tree"
                },
                {
                    "type": "File",
                    "outputSource": "#main/codeml/results",
                    "label": "dN/dS results",
                    "id": "#main/results"
                }
            ],
            "steps": [
                {
                    "run": "#clustalo.cwl",
                    "in": [
                        {
                            "source": "#main/proteins_to_align",
                            "id": "#main/clustal/multi_sequence"
                        }
                    ],
                    "out": [
                        "#main/clustal/alignment",
                        "#main/clustal/guide_tree"
                    ],
                    "id": "#main/clustal"
                },
                {
                    "run": "#codeml.cwl",
                    "in": [
                        {
                            "source": "#main/pal2nal/alignment",
                            "id": "#main/codeml/sequences"
                        },
                        {
                            "source": "#main/clustal/guide_tree",
                            "id": "#main/codeml/tree"
                        }
                    ],
                    "out": [
                        "#main/codeml/results"
                    ],
                    "id": "#main/codeml"
                },
                {
                    "run": "#pal2nal.cwl",
                    "in": [
                        {
                            "source": "#main/nucleotides",
                            "id": "#main/pal2nal/nucleotides"
                        },
                        {
                            "source": "#main/clustal/alignment",
                            "id": "#main/pal2nal/protein_alignment"
                        }
                    ],
                    "out": [
                        "#main/pal2nal/alignment"
                    ],
                    "id": "#main/pal2nal"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
